Computation times — Python documentation

# Computation times

00:04.946 total execution time for auto_examples files:

Animation support (`plot_animation.py`) | 00:03.815 | 0.0 MB
Pickling (`plot_pickle.py`) | 00:00.313 | 0.0 MB
Matplotlib alt text (`plot_matplotlib_alt.py`) | 00:00.297 | 0.0 MB
Error during scraping (`plot_scraper_broken.py`) | 00:00.231 | 0.0 MB
Link to other packages (`plot_numpy_matplotlib.py`) | 00:00.162 | 0.0 MB
“SVG”:-graphics_ (`plot_svg.py`) | 00:00.085 | 0.0 MB
Command line arguments support (`plot_command_line_args.py`) | 00:00.042 | 0.0 MB
Logging test (`plot_log.py`) | 00:00.002 | 0.0 MB
Testing future statements across examples (`plot_second_future_imports.py`) | 00:00.001 | 0.0 MB
sphx_glr_auto_examples_local_module.py (`local_module.py`) | 00:00.000 | 0.0 MB